% Supplementary material for the paper
% M.Scali, P.A.H. Veldhoven, P.W.J. Henselmans, D. Dodou, P.Breedveld (2019). Design of an ultra-thin 
% steerable probe for percutaneous interventions and preliminary evaluation in a gelatine phantom. PLOS ONE.
% Tested in MATLAB 2016b

clc; close all;clear; 

 %% load files

load ('Data_Deflection.mat')

%% Factor front view
DFactorFront=cell(9,5);

for n=1:9
    for m=1:5
        if(n==3 && m==4)||(n==3 && m==5)||(n==4 && m==4)||(n==6 && m==5)||(n==9 && m==4)||(n==9 && m==5)
            DFactorFront{n,m}=120/1110;
        else 
            DFactorFront{n,m}=120/1024;
        end
    end
end
        
%% differences in pixels

DXFDiff = cell(9,5);
DYFDiff = cell(9,5);
DXSDiff = cell(9,5);
DYSDiff = cell(9,5);

for n=1:9
    for m=1:5
        DXFDiff {n,m}= DXfront{n,m}-DXfrontIn_manual{n,m}; %deflection front
        DYFDiff {n,m}= DYfront{n,m}-DYfrontIn_manual{n,m}; %depth front
        DXSDiff {n,m}= DXside{n,m}-DXsideIn{n,m}; %deflection side
        DYSDiff {n,m}= DYside{n,m}-DYsideIn{n,m};%depth side
    end
end

%% determine factor for sideview // this factor will be different for each measurement

 DFactorSide = cell(9,5);
 
for n=1:9
    for m=1:5
    DFactorSide{n,m}=((DFactorFront{n,m}.*DYFDiff{n,m})./DYSDiff{n,m});
    end
end

%% correct factor side manually

DFactorSide{3,4}=FactorSide_3_4;
DFactorSide{9,1}=DFactorSide{1,1};

%% polar coordinates of the final position of the needle in 3D

Theta_all = cell(9,5);
rho_all = cell(9,5);

for n=1:9
    for m=1:5
    [Theta, rho]= cart2pol((DXFDiff{n,m}.*DFactorFront{n,m}), (DXSDiff{n,m}.*DFactorSide{n,m}));
    Theta_all{n,m}=Theta;
    rho_all{n,m}=rho;
    end
end

%% theta and rho from corrected images

Theta_all{1,5}=Theta_1_5;
Theta_all{2,5}=Theta_2_5;
Theta_all{4,5}=Theta_4_5;
Theta_all{6,5}=Theta_6_5;
Theta_all{7,5}=Theta_7_5;

rho_all{1,5}=rho_1_5;
rho_all{2,5}=rho_2_5;
rho_all{4,5}=rho_4_5;
rho_all{6,5}=rho_6_5;
rho_all{7,5}=rho_7_5;

%% theta from rad to deg

Angle = cell(9,5);

for n=1:9
    for m=1:5
    Angledeg2 = rad2deg(Theta_all{n,m});
    Angle{n,m}= Angledeg2;
    if (Angledeg2<0)
    Angle{n,m}=360 + Angledeg2;
    end
    end
end


%% depth in mm

Depth = cell(9,5);

for n=1:9
    for m=1:5
        Depth{n,m}= DYFDiff{n,m}.*DFactorFront{n,m}; %depth 
    end
end

%% depth corrected

Depth{1,5}=Depth_1_5;
Depth{2,5}=Depth_2_5;
Depth{4,5}=Depth_4_5;
Depth{6,5}=Depth_6_5;
Depth{7,5}=Depth_7_5;

%% deflection-to-insertion depth ratio

ratio= cell(9,5);

for n=1:9
    for m=1:5
        ratio{n,m} = rho_all{n,m}./Depth{n,m}; 
    end
end


%% Median and interquartile range

deflection=cell2mat(rho_all);
ratio2=cell2mat(ratio);
depth = cell2mat(Depth);

median_deflection = zeros(9,1);
iqr_deflection = zeros(9,1);
median_ratio = zeros(9,1);
iqr_ratio = zeros(9,1);
median_depth = zeros(9,1);
iqr_depth = zeros(9,1);

for n = 1:9
   if (n==6)
   median_deflection(n,1) = median(deflection(n,1:4));
   iqr_deflection(n,1) = iqr(deflection(n,1:4));
   else
   median_deflection(n,1) = median(deflection(n,:));
   iqr_deflection(n,1) = iqr(deflection(n,:));
   end
end

for n = 1:9
   if (n==6)
   median_ratio(n,1) = median(ratio2(n,1:4));
   iqr_ratio(n,1) = iqr(ratio2(n,1:4));
   else
   median_ratio(n,1) = median(ratio2(n,:));
   iqr_ratio(n,1) = iqr(ratio2(n,:));
   end 
end

for n = 1:9
   if (n==6)
   median_depth(n,1) = median(depth(n,1:4));
   iqr_depth(n,1) = iqr(depth(n,1:4));
   else
   median_depth(n,1) = median(depth(n,:));
   iqr_depth(n,1) = iqr(depth(n,:));
   end 
end

%% percentile Q1 and Q3

Q1Q3_ratio = cell(1,9);
Q1Q3_deflection = cell(1,9);
Q1Q3_depth = cell(1,9);

for n = 1:9
   if (n==1)||(n==2)||(n==4)||(n==6)||(n==7)
   Q1Q3_ratio {n} = prctile(ratio2(n,1:4),[25 75]);
   else
   Q1Q3_ratio {n} = prctile(ratio2(n,:),[25 75]);
   end
end


for n = 1:9
   if (n==1)||(n==2)||(n==4)||(n==6)||(n==7)
   Q1Q3_deflection {n} = prctile(deflection(n,1:4),[25 75]);
   Q1Q3_depth {n} = prctile(depth(n,1:4),[25 75]);
   else
   Q1Q3_deflection {n} = prctile(deflection(n,:),[25 75]);
   Q1Q3_depth {n} = prctile(depth(n,:),[25 75]);
   end
end


%% [extra] 2D plot deflection front view vs. insertion depth

% DXFDiff_mm = cell(9,5);
% 
% for n=1:9
%     for m=1:5
%         DXFDiff_mm{n,m}= DXFDiff{n,m}.*DFactorFront{n,m}; %
%     end
% end
% DXFDiff2=cell2mat(DXFDiff_mm);
% 
% figure 
% plot(DXFDiff2(1,:),depth(1,:),'k o','MarkerFaceColor','b','Markersize',8)
% hold on
% plot(DXFDiff2(2,:),depth(2,:),'k ^','MarkerFaceColor','g','Markersize',8)
% hold on
% plot(DXFDiff2(3,:),depth(3,:),'k >','MarkerFaceColor','c','Markersize',8)
% hold on
% plot(DXFDiff2(4,:),depth(4,:),'k <','MarkerFaceColor','r','Markersize',8)
% hold on
% plot(DXFDiff2(5,:),depth(5,:),'k s','MarkerFaceColor','y','Markersize',8)
% hold on
% plot(DXFDiff2(6,1:4),depth(6,1:4),'k *','Markersize',8)
% hold on
% plot(DXFDiff2(7,:),depth(7,:),'k d','MarkerFaceColor','w','Markersize',8)
% hold on
% plot(DXFDiff2(8,:),depth(8,:),'k p','MarkerFaceColor','k','Markersize',8)
% hold on
% plot(DXFDiff2(9,:),depth(9,:),'k h','MarkerFaceColor','m','Markersize',8)
% 
% title('Front view')
% xlabel('Deflection')
% ylabel('Insertion depth')
% legend('Condition 1', 'Condition 2', 'Condition 3', 'Condition 4', 'Condition 5', 'Condition 6', 'Condition 7', 'Condition 8', 'Condition 9')
% 
% ax = gca;
% ax.FontName= 'Times New Roman';
% ax.FontSize=12;
% ax. XGrid = 'on';
% ax. YGrid = 'on';
% ax.XLim= [-10 100];
% ax.YLim= [0 65];
% ax.YDir='reverse';
% ax.XAxisLocation = 'top';

%% [extra] 2D deflection side view vs. insertion depth
% 
% DXSDiff_mm = cell(9,5);
% 
% for n=1:9
%     for m=1:5
%         DXSDiff_mm{n,m}= DXSDiff{n,m}.*DFactorSide{n,m}; %
%     end
% end
% DXSDiff2=cell2mat(DXSDiff_mm);
% 
% figure 
% plot(DXSDiff2(1,:),depth(1,:),'k o','MarkerFaceColor','b','Markersize',8)
% hold on
% plot(DXSDiff2(2,:),depth(2,:),'k ^','MarkerFaceColor','g','Markersize',8)
% hold on
% plot(DXSDiff2(3,:),depth(3,:),'k >','MarkerFaceColor','c','Markersize',8)
% hold on
% plot(DXSDiff2(4,:),depth(4,:),'k <','MarkerFaceColor','r','Markersize',8)
% hold on
% plot(DXSDiff2(5,:),depth(5,:),'k s','MarkerFaceColor','y','Markersize',8)
% hold on
% plot(DXSDiff2(6,1:4),depth(6,1:4),'k *','Markersize',8)
% hold on
% plot(DXSDiff2(7,:),depth(7,:),'k d','MarkerFaceColor','w','Markersize',8)
% hold on
% plot(DXSDiff2(8,:),depth(8,:),'k p','MarkerFaceColor','k','Markersize',8)
% hold on
% plot(DXSDiff2(9,:),depth(9,:),'k h','MarkerFaceColor','m','Markersize',8)
% 
% title('Side view')
% xlabel('Deflection')
% ylabel('Insertion depth')
% legend('Condition 1', 'Condition 2', 'Condition 3', 'Condition 4', 'Condition 5', 'Condition 6', 'Condition 7', 'Condition 8', 'Condition 9')
% 
% ax = gca;
% ax.FontName= 'Times New Roman';
% ax.FontSize=12;
% ax. XGrid = 'on';
% ax. YGrid = 'on';
% ax.XLim= [-10 100];
% ax.YLim= [0 65];
% ax.YDir='reverse';
% ax.XAxisLocation = 'top';

%% [extra] 3D plot
% figure
% 
% scatter3(DXSDiff2(1,:),DXFDiff2(1,:),depth(1,:),'k o','MarkerFaceColor','b')
% hold on
% scatter3(DXSDiff2(2,:),DXFDiff2(2,:),depth(2,:),'k ^','MarkerFaceColor','g')
% hold on 
% scatter3(DXSDiff2(3,:),DXFDiff2(3,:),depth(3,:),'k >','MarkerFaceColor','c')
% hold on
% scatter3(DXSDiff2(4,:),DXFDiff2(4,:),depth(4,:),'k <','MarkerFaceColor','r')
% hold on
% scatter3(DXSDiff2(5,:),DXFDiff2(5,:),depth(5,:),'k s','MarkerFaceColor','y')
% hold on 
% scatter3(DXSDiff2(6,:),DXFDiff2(6,:),depth(6,:),'k *')
% hold on
% scatter3(DXSDiff2(7,:),DXFDiff2(7,:),depth(7,:),'k d','MarkerFaceColor','w')
% hold on
% scatter3(DXSDiff2(8,:),DXFDiff2(8,:),depth(8,:),'k p','MarkerFaceColor','k')
% hold on
% scatter3(DXSDiff2(9,:),DXFDiff2(9,:),depth(9,:),'k h','MarkerFaceColor','m')
% 
% set(gca,'Ydir','reverse','Zdir','reverse')
% zlim([0 65])
% 
% xlabel('deflection - side view')
% ylabel('deflection - front view')
% zlabel('insertion depth')
% legend('Condition 1', 'Condition 2', 'Condition 3', 'Condition 4', 'Condition 5', 'Condition 6', 'Condition 7', 'Condition 8', 'Condition 9')
 

%% plot data points deflection-to-insertion depth ratio

figure
R=[ratio2(1,:) ratio2(2,:) ratio2(3,:) ratio2(4,:) ratio2(5,:) ratio2(6,1:4) ratio2(7,:) ratio2(8,:) ratio2(9,:)];
grp = [ones(1,5), 2.*ones(1,5), 3.*ones(1,5), 4.*ones(1,5), 5.*ones(1,5), 6.*ones(1,4), 7.*ones(1,5), 8.*ones(1,5), 9.*ones(1,5)];
boxplot(R, grp, 'Colors', 'k')
hold on
plot([1 1 1 1 1],ratio2(1,:),'o','Markersize',8,'MarkerEdgeColor','k', 'LineWidth',1.5)%,'MarkerFaceColor','r')
hold on
plot([2 2 2 2 2],ratio2(2,:),'o','Markersize',8,'MarkerEdgeColor','k','LineWidth',1.5)
hold on
plot([3 3 3 3 3],ratio2(3,:),'o','Markersize',8,'MarkerEdgeColor','k','LineWidth',1.5)
hold on
plot([4 4 4 4 4],ratio2(4,:),'o','Markersize',8,'MarkerEdgeColor','k','LineWidth',1.5)
hold on
plot([5 5 5 5 5],ratio2(5,:),'o','Markersize',8,'MarkerEdgeColor','k','LineWidth',1.5)
hold on
plot([6 6 6 6],ratio2(6,1:4),'o','Markersize',8,'MarkerEdgeColor','k','LineWidth',1.5)
hold on
plot([7 7 7 7 7],ratio2(7,:),'o','Markersize',8,'MarkerEdgeColor','k', 'LineWidth',1.5)
hold on
plot([8 8 8 8 8],ratio2(8,:),'o','Markersize',8,'MarkerEdgeColor','k', 'LineWidth',1.5)
hold on
plot([9 9 9 9 9],ratio2(9,:),'o','Markersize',8,'MarkerEdgeColor','k', 'LineWidth',1.5)

xlabel('Conditions')
ylabel('Deflection-to-insertion depth ratio')

ax = gca;
ax.FontName= 'Times New Roman';
ax.FontSize= 24;
ax.XLim = [0 10];
ax.YLim = [0 14];
ax.XTickLabel= {'1','2','3','4','5','6','7','8','9'};
ax.YTick=[0 1 2 3 4 5 6 7 8 9 10 11 12 13 14];
ax.YTickLabel={'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14'};
ax. YGrid = 'on';

%% tables

Conditions = (1:9)';

% Deflection
Median = round(median_deflection,2);
IQR = round(iqr_deflection,2);
Deflection = table(Conditions, Median, IQR);
disp(Deflection)

%Depth
Median = round(median_depth,2);
IQR = round(iqr_depth,2);
Depth = table(Conditions, Median, IQR);
disp(Depth)

%Ratio
Median = round(median_ratio,2);
IQR = round(iqr_ratio,2);
Ratio = table(Conditions, Median, IQR);
disp(Ratio)

