% Supplementary material for the paper
% M.Scali, P.A.H. Veldhoven, P.W.J. Henselmans, D. Dodou, P.Breedveld (2019). Design of an ultra-thin 
% steerable probe for percutaneous interventions and preliminary evaluation in a gelatine phantom. PLOS ONE.
% Tested in MATLAB 2016b

clc; close all; clear;  

%% load files

load('Data_Direction.mat');

%% Set constants

num_cond=6;
num_trial=5;

%% Factor front view, calculated with distance between the points of the gelatine box

FactorFront = 0.1076;

%% difference dx and dy 
%Determine difference between points
 
 XFrontDiff = cell(num_cond,num_trial);
 YFrontDiff = cell(num_cond,num_trial);
 XSideDiff = cell(num_cond,num_trial);
 YSideDiff = cell(num_cond,num_trial);
 
 for n = 1:num_cond
     
     for m = 1:num_trial
         
        FDiffx = Xfront{n,m} - XfrontIn{n,m};
        FDiffy = Yfront{n,m} - YfrontIn{n,m};
        XFrontDiff{n,m} = FDiffx;
        YFrontDiff{n,m} = FDiffy;
        SDiffx = Xside{n,m} - XsideIn{n,m};
        SDiffy = Yside{n,m} - YsideIn{n,m};
        XSideDiff{n,m} = SDiffx;
        YSideDiff{n,m} = SDiffy;
        
     end
 end
 
%% determine factor for sideview 

FactorSide = zeros(6,5);

for n=1:6
    for m=1:5
    FactorSide(n,m)=((FactorFront.*YFrontDiff{n,m})./YSideDiff{n,m}); %vector n rows and 1 coloumn
    end
end

%% depth in mm

Front_depth = cell(6,5);
Side_depth = cell(6,5);

for n=1:6
    for m=1:5
        Front_depth{n,m}= YFrontDiff{n,m}.*FactorFront; %depth front
        Side_depth{n,m} = YSideDiff{n,m}.*FactorSide(n,m); %depth side
    end
end

%% theta and rho
% theta = atan (y,x) , y -> XsideDiff  x-> Xfront Diff

Theta_all = cell(num_cond,num_trial);
rho_all = cell(num_cond,num_trial);

for n=1:num_cond
    for m=1:num_trial
        [Theta, rho]= cart2pol((XFrontDiff{n,m})*FactorFront, (XSideDiff{n,m}).*FactorSide(n,m)); 
        Theta_all{n,m}=Theta; %in radiants
        rho_all{n,m}=rho;
    end
end

%% theta from rad to deg

Angle = cell(6,5);

for n=1:num_cond
    for m=1:num_trial
    Angledeg2 = rad2deg(Theta_all{n,m});
    Angle{n,m}= Angledeg2;
    end
end 

%% correct negative angles, when an angle is negative it means that it is in between 180 and 360 degrees.

AngleNeg = Angle;
for n=1:num_cond
    for m=1:num_trial
if (Angle{n,m}<0)
    Angle{n,m}=360 + Angle{n,m};
end
    end
end


%% plot view from the top of the final points with angle (theta) and distance from the axes (rho)

figure 
polarplot((cell2mat(Theta_all(1,:)))',(cell2mat(rho_all(1,:)))','k o','MarkerFaceColor','k','MarkerSize',10);
hold on
polarplot((cell2mat(Theta_all(2,:)))',(cell2mat(rho_all(2,:)))','k s','MarkerFaceColor','y','MarkerSize',10);
hold on
polarplot((cell2mat(Theta_all(3,:)))',(cell2mat(rho_all(3,:)))','k d','MarkerFaceColor','g','MarkerSize',10);
hold on 
polarplot((cell2mat(Theta_all(4,:)))',(cell2mat(rho_all(4,:)))','k v','MarkerFaceColor','b','MarkerSize',10);
hold on
polarplot((cell2mat(Theta_all(5,:)))',(cell2mat(rho_all(5,:)))','k p','MarkerFaceColor','r','MarkerSize',10);
hold on
polarplot((cell2mat(Theta_all(6,:)))',(cell2mat(rho_all(6,:)))','k h','MarkerFaceColor','c','MarkerSize',10);

legend('Condition 1','Condition 2','Condition 3','Condition 4','Condition 5','Condition 6')
ax = gca;
ax.FontName= 'Times New Roman';
ax.FontSize = 21;
ax.ThetaTickLabel = {'0', '30', '60', '90', '120', '150', '180', '210', '240', '270', '300', '330', '360'};
ax.RAxisLocation=0;
ax.RLim=[0 50];
ax.RTick=[0 10 20 30 40 50];
ax.RTickLabel={'0','','20 mm','','40 mm',''};
set(gca, 'color', 'none');

%% median & mean

direction = cell2mat(Angle);
mean_direction = zeros(6,1);
std_direction = zeros(6,1);
median_direction = zeros(6,1);

for n = 1:6
   mean_direction(n,1) = mean(direction(n,:));
   std_direction(n,1) = std(direction(n,:));
   median_direction(n,1) = median(direction(n,:));
end

%% median and interquartile range

direction2 = direction';
median_direction = median(direction2);
interqrange_direction = iqr(direction2);
Q1Q3_direction {n} = prctile(direction2,[25 75]);


%% differences between the single element retraction 

diff1 = (360 - mean_direction(3)) + mean_direction(1);
diff2 = mean_direction(3) - mean_direction (5);
diff3 = mean_direction (5) - mean_direction(1);

diff4 = (360 - median_direction(3)) + median_direction(1);
diff5 = median_direction(3) - median_direction(5);
diff6 = median_direction(5) - median_direction(1);

diff7 = mean_direction(2) - mean_direction (4);
diff8 = mean_direction(4) - mean_direction (6);
diff9 = (360 - mean_direction(2)) + mean_direction (6);

diff10 = median_direction(2) - median_direction (4);
diff11 = median_direction(4) - median_direction (6);
diff12 = (360 - median_direction(2)) + median_direction (6);

%% double element retraction

diff13 = mean_direction(5)-mean_direction(6);
diff14 = mean_direction(4)-mean_direction(5);
diff15 = mean_direction(3)-mean_direction(4);
diff16 = mean_direction(2)-mean_direction(3);
diff17 = (360 - mean_direction(2)) + mean_direction(1);
diff18 = mean_direction(6) - mean_direction(1);

diff13b = median_direction(5)-median_direction(6);
diff14b = median_direction(4)-median_direction(5);
diff15b = median_direction(3)-median_direction(4);
diff16b = median_direction(2)-median_direction(3);
diff17b = (360 - median_direction(2)) + median_direction(1);
diff18b = median_direction(6) - median_direction(1);

%% table Direction Angle

Conditions = (1:6)';
Median = round(median_direction,1)';
IQR = round(interqrange_direction,1)';
DirectionAngle = table(Conditions, Median, IQR);
disp(DirectionAngle)


